d3.text(
  'https://raw.githubusercontent.com/hemalatha1700/DataVisualization_repo/main/output_file.csv',
).then(function (text) {
  // Split the text into lines
  const lines = text.trim().split('\n');

  // Initialize an empty array to store the data
  const data = [];

  for (let i = 1; i < lines.length; i++) {
    const [
      Monthyear,
      Africa,
      Asia,
      Europe,
      NorthAmerica,
      ocenia,
      SouthAmerica,
    ] = lines[i].split(',');
    console.log(
      Monthyear,
      Africa,
      Asia,
      Europe,
      NorthAmerica,
      ocenia,
      SouthAmerica,
    ); // Debugging
    data.push({
      Month: Monthyear,
      Africa: +Africa,
      Asia: +Asia,
      Europe: +Europe,
      NorthAmerica: +NorthAmerica,
      ocenia: +ocenia,
      SouthAmerica: +SouthAmerica,
    });
  }
  // Ensure data parsing
  console.log(data); // Debugging

  // Setup SVG
  const margin = {
    top: 20,
    right: 20,
    bottom: 30,
    left: 80,
  };
  const width = 1500 - margin.left - margin.right;
  const height = 700 - margin.top - margin.bottom;

  const svg = d3
    .select('svg')
    .attr('width', width + margin.left + margin.right)
    .attr('height', height + margin.top + margin.bottom)
    .append('g')
    .attr(
      'transform',
      'translate(' + margin.left + ',' + margin.top + ')',
    );

  // Set up scales
  const xScale = d3
    .scaleBand()
    .domain(data.map((d) => d.Month))
    .range([0, width])
    .padding(0.3);

  const yScale = d3
    .scaleLinear()
    .domain([1000, 3600000]) // Set domain to 0-100
    .range([height, 0]);

  // Draw lines
  const line = d3
    .line()
    .x((d) => xScale(d.Month) + xScale.bandwidth() / 2)
    .y((d) => yScale(d.Africa))
    .curve(d3.curveLinear);

  svg
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'red')
    .attr('stroke-width', 1)
    .attr('d', line);

  const line2 = d3
    .line()
    .x((d) => xScale(d.Month) + xScale.bandwidth() / 2)
    .y((d) => yScale(d.Asia))
    .curve(d3.curveLinear);

  svg
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'blue')
    .attr('stroke-width', 1)
    .attr('d', line2);

  const line3 = d3
    .line()
    .x((d) => xScale(d.Month) + xScale.bandwidth() / 2)
    .y((d) => yScale(d.Europe))
    .curve(d3.curveLinear);

  svg
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'green')
    .attr('stroke-width', 1)
    .attr('d', line3);

  const line4 = d3
    .line()
    .x((d) => xScale(d.Month) + xScale.bandwidth() / 2)
    .y((d) => yScale(d.NorthAmerica))
    .curve(d3.curveLinear);
  svg
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'orange')
    .attr('stroke-width', 1)
    .attr('d', line4);
  const line5 = d3
    .line()
    .x((d) => xScale(d.Month) + xScale.bandwidth() / 2)
    .y((d) => yScale(d.ocenia))
    .curve(d3.curveLinear);
  svg
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'black')
    .attr('stroke-width', 1)
    .attr('d', line5);

  const line6 = d3
    .line()
    .x((d) => xScale(d.Month) + xScale.bandwidth() / 2)
    .y((d) => yScale(d.SouthAmerica))
    .curve(d3.curveLinear);

  svg
    .append('path')
    .datum(data)
    .attr('fill', 'none')
    .attr('stroke', 'purple')
    .attr('stroke-width', 1)
    .attr('d', line6);

  // Add tooltip
  const tooltip = d3
    .select('body')
    .append('div')
    .attr('id', 'tooltip')
    .style('position', 'absolute')
    .style('visibility', 'hidden')
    .style('background-color', 'brown')
    .style('color', 'white')
    .style('padding', '5px')
    .style('border-radius', '5px')
    .style('box-shadow', '0 0 10px rgba(0, 0, 0, 0.2)');

  // Draw dots for NYC
  svg
    .selectAll('.dot-Africa')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot-Africa')
    .attr(
      'cx',
      (d) => xScale(d.Month) + xScale.bandwidth() / 2,
    )
    .attr('cy', (d) => yScale(d.Africa))
    .attr('r', 4)
    .attr('fill', 'red')
    .on('mouseover', function (event, d) {
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${d.Month}</strong><br/>Africa: ${d.Africa}`,
        )
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', function () {
      d3.select('#tooltip').style('visibility', 'hidden');
    });

  // Draw dots for LA
  svg
    .selectAll('.dot-Asia')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot-Asia')
    .attr(
      'cx',
      (d) => xScale(d.Month) + xScale.bandwidth() / 2,
    )
    .attr('cy', (d) => yScale(d.Asia))
    .attr('r', 4)
    .attr('fill', 'blue')
    .on('mouseover', function (event, d) {
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${d.Month}</strong><br/>Asia: ${d.Asia}`,
        )
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', function () {
      d3.select('#tooltip').style('visibility', 'hidden');
    });

  // Draw dots for Europe
  svg
    .selectAll('.dot-Europe')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot-Europe')
    .attr(
      'cx',
      (d) => xScale(d.Month) + xScale.bandwidth() / 2,
    )
    .attr('cy', (d) => yScale(d.Europe))
    .attr('r', 4)
    .attr('fill', 'green')
    .on('mouseover', function (event, d) {
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${d.Month}</strong><br/>Europe: ${d.Europe}`,
        )
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', function () {
      d3.select('#tooltip').style('visibility', 'hidden');
    });

  // Draw dots for Houston
  svg
    .selectAll('.dot-NorthAmerica')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot-NorthAmerica')
    .attr(
      'cx',
      (d) => xScale(d.Month) + xScale.bandwidth() / 2,
    )
    .attr('cy', (d) => yScale(d.NorthAmerica))
    .attr('r', 4)
    .attr('fill', 'orange')
    .on('mouseover', function (event, d) {
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${d.Month}</strong><br/>NorthAmerica: ${d.NorthAmerica}`,
        )
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', function () {
      d3.select('#tooltip').style('visibility', 'hidden');
    });

  // draw dots for ocenia
  svg
    .selectAll('.dot-ocenia')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot-ocenia')
    .attr(
      'cx',
      (d) => xScale(d.Month) + xScale.bandwidth() / 2,
    )
    .attr('cy', (d) => yScale(d.ocenia))
    .attr('r', 4)
    .attr('fill', 'black')
    .on('mouseover', function (event, d) {
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${d.Month}</strong><br/>ocenia: ${d.ocenia}`,
        )
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', function () {
      d3.select('#tooltip').style('visibility', 'hidden');
    });

  // southamerica
  svg
    .selectAll('.dot-SouthAmerica')
    .data(data)
    .enter()
    .append('circle')
    .attr('class', 'dot-SouthAmerica')
    .attr(
      'cx',
      (d) => xScale(d.Month) + xScale.bandwidth() / 2,
    )
    .attr('cy', (d) => yScale(d.SouthAmerica))
    .attr('r', 4)
    .attr('fill', 'purple')
    .on('mouseover', function (event, d) {
      const tooltip = d3.select('#tooltip');
      tooltip
        .style('visibility', 'visible')
        .html(
          `<strong>${d.Month}</strong><br/>SouthAmerica: ${d.SouthAmerica}`,
        )
        .style('left', event.pageX + 10 + 'px')
        .style('top', event.pageY - 28 + 'px');
    })
    .on('mouseout', function () {
      d3.select('#tooltip').style('visibility', 'hidden');
    });

  // Draw legend
  const legend = svg
    .append('g')
    .attr('class', 'legend')
    .attr(
      'transform',
      'translate(' + (width - 40) + ',' + 20 + ')',
    );

  legend
    .append('text')
    .attr('x', 0)
    .attr('y', 0)
    .attr('fill', 'red')
    .text('Africa');

  legend
    .append('text')
    .attr('x', 0)
    .attr('y', 20)
    .attr('fill', 'blue')
    .text('Asia');

  legend
    .append('text')
    .attr('x', 0)
    .attr('y', 40)
    .attr('fill', 'green')
    .text('Europe');

  legend
    .append('text')
    .attr('x', 0)
    .attr('y', 60)
    .attr('fill', 'orange')
    .text('NorthAmerica');

  legend
    .append('text')
    .attr('x', 0)
    .attr('y', 80)
    .attr('fill', 'black')
    .text('ocenia');

  legend
    .append('text')
    .attr('x', 0)
    .attr('y', 100)
    .attr('fill', 'purple')
    .text('SouthAmerica');

  // Draw axes
  svg
    .append('g')
    .attr('transform', 'translate(0,' + height + ')')
    .call(d3.axisBottom(xScale))
    .selectAll('text')
    .attr('dy', '2em') // Adjust the label's position
    .style('text-anchor', 'end');

  svg.append('g').call(d3.axisLeft(yScale).ticks(13)); // Adjust ticks for increments of 10
});
